Enum CaseMatching
pub enum CaseMatching {
Exact,
CaseInsensitive,
}Expand description
A policy for case matching. There may be more choices in the future (for example, an even more forgiving mode that ignores accents, or possibly handling Unicode normalization).
Variants
Exact
Require an exact codepoint-for-codepoint match (implies case sensitivity).
CaseInsensitive
Case insensitive match. Guaranteed to work for the ASCII case, and
reasonably well otherwise (it is currently defined in terms of the
to_lowercase methods in the Rust standard library).